import csv
from datetime import datetime, timedelta
import argparse

def convert_timestamps(input_file_path, output_file_path, timezone_offset):
    datetime_format = "%Y-%m-%d,%H:%M:%S.%f"
    
    with open(input_file_path, 'r', encoding='utf-8') as infile, open(output_file_path, 'w', encoding='utf-8', newline='') as outfile:
        reader = csv.reader(infile)
        writer = csv.writer(outfile, quoting=csv.QUOTE_MINIMAL)
        
        for row in reader:
            date_str, time_str = row[0], row[1]
            datetime_str = f'{date_str},{time_str}'
            datetime_obj = datetime.strptime(datetime_str, datetime_format)
            converted_datetime_obj = datetime_obj + timedelta(hours=timezone_offset)
            
            row[1] = converted_datetime_obj.strftime("%H:%M:%S.%f")[:-3]
            if datetime_obj.date() != converted_datetime_obj.date():
                row[0] = converted_datetime_obj.strftime("%Y-%m-%d")
            
            writer.writerow(row)

if __name__ == "__main__":
    parser = argparse.ArgumentParser(description="Convert timestamps in a CSV file to a different timezone.")
    parser.add_argument("input_file", help="The path to the input CSV file.")
    parser.add_argument("output_file", help="The path to the output CSV file.")
    parser.add_argument("timezone_offset", type=int, help="The timezone offset to apply (in hours).")
    
    args = parser.parse_args()
    
    convert_timestamps(args.input_file, args.output_file, args.timezone_offset)
